@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "helm-projectile" "1.4.0"
+(define-package "helm-projectile" "20250902.830"
   "Helm integration for Projectile."
   '((emacs      "26.1")
     (helm       "3.0")
